@@ -363,7 +363,7 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
         :param timeframe: bt.TimeFrame
         :param compression: distance between samples. e.g if 1 =>
                  get sample every day. if 3 => get sample every 3 days
-        :param candleFormat: (bidask, midpoint, trades)
+        :param candleFormat: (bidask, midpoint, trades) - not used we get bars
         :param includeFirst:
         :return:
         """
@@ -475,6 +475,10 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
             dtbegin = dtend - delta
         else:
             dtbegin = pd.Timestamp(pytz.timezone(NY).localize(dtbegin))
+        while dtbegin > dtend:
+            # if we start the script during market hours we could get this
+            # situation. this resolves that.
+            dtbegin -= timedelta(days=1)
         return dtbegin, dtend
 
     def get_aggs_from_polygon(self,
@@ -514,7 +518,12 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
             segment_start = dtbegin
             segment_end = segment_start + timedelta(weeks=2) if \
                 dtend - dtbegin >= timedelta(weeks=2) else dtend
-            while segment_end <= dtend and dtend not in cdl.index:
+            while segment_end <= dtend:
+                if not cdl.empty and dtend <= cdl.index[-1]:
+                    # when resampling the data dtend is not promised to be
+                    # a part of cdl. we just want to make sure we have data
+                    # that should contain it.
+                    break
                 response = self.oapi.polygon.historic_agg_v2(
                     dataname,
                     compression,
@@ -674,7 +683,7 @@ class AlpacaStore(with_metaclass(MetaSingleton, object)):
             response = _resample(cdl)
         # response = _back_to_aggs(cdl)
         else:
-            response = response.df
+            response = cdl
         response = response.dropna()
         response = response[~response.index.duplicated()]
         return response
